@@ -3,17 +3,20 @@ import numpy as np
 import json
 import base64
 
-from .processing import GetTemplateGuidFromPath
-from mka_eureka_microservice_controllers.shared_scripts import mka_requests
-from .base64_converter import Base64Converter
-from .services_managment import ServiceController,Services
+from .mka_processing import GetTemplateGuidFromPath
+from .mka_base64_converter import Base64Converter
+from .mka_services_managment import ServiceController,Services
 
 class ParamsMapper(object):
     DICTIONARY_LIST_TYPE="DictionaryList"
 
     _key_for_all_requests={
-
+            ######################## for all services ########################
             "file_path_info": {"type":DICTIONARY_LIST_TYPE,"has_default":True,"default":[]},
+            "sheet":{"type":any,"has_default":True,"default":None},
+
+
+            #########################******* for text analysis service *******########################
             "keywords_count": {"type":int,"has_default":True,"default":4},
             "keywords_algorithms": {"type":list,"has_default":True,"default":["YAKE"]},
             "sentiment_option": {"type":dict,"has_default":True,"default":{"name": "Text", "value": None}},
@@ -23,8 +26,63 @@ class ParamsMapper(object):
             "selected_analysis_type": {"type":list,"has_default":False},
             "summary_algorithm": {"type":list,"has_default":True,"default": ["LEX_RANK"]},
             "minimizing_approach": {"type":dict,"has_default":True,"default": {'action': 'numberOfBestSentences', 'value': 5}},
-    }
+            
+            
+            ########################******* for machine learning service ********########################
 
+            #++++++++++++++++++++++++++++++ fit model ++++++++++++++++++++++++++++++#
+            
+            "features": {"type": list,"has_default":False},
+            "algorithms": {"type": list,"has_default":True,"default":[]},
+            "ml_method": {"type": str,"values":["Regression","Classification","Clustering"],"has_default":False},
+            "auto_select_algorithms": {"type": bool,"has_default":False},
+
+
+
+            #++++++++++++++++++++++++++++++ Predictive(Classification,Regression) Train ++++++++++++++++++++++++++++++#
+
+            "label":{"type":str,"has_default":False},
+            "split_mechanism": {"type": str,"values":['k_fold','random'],"has_default":True,"default":"random"},
+            "train_size": {"type": float,"has_default":False},
+            "count_of_folds": {"type": int,"has_default":False,"default":5},
+            "continuous_target_to_discrete": {"type": bool,"has_default":True,"default":False},
+            "contiuous_encoding": {"type": bool,"has_default":True,"default":False},
+            "remove_to_many_values": {"type": bool,"has_default":True,"default":False},
+            "extract_date_info": {"type":bool,"has_default":True,"default":False},
+
+
+
+            #++++++++++++++++++++++++++++++ Non-Predictive(Clustering) Train ++++++++++++++++++++++++
+
+            "min_clusters": {"type": int,"has_default":True,"default":2},
+            "max_clusters": {"type": int,"has_default":True,"default":20},
+            "fully_tree": {"type": bool,"has_default":True,"default":False},
+
+
+
+            #++++++++++++++++++++++++++++++ Predict Values ++++++++++++++++++++++++++++++#
+
+            "predict_data": {"type":DICTIONARY_LIST_TYPE,"attributes":["Name","value"],"has_default":False},
+            "model_path": {"type": str,"has_default":False},
+
+
+            #++++++++++++++++++++++++++++++ Change Clustering Groups names ++++++++++++++++++++++++++++++#
+
+            "clusters_map": {"type":dict,"has_default":False},
+            "clusters_column": {"type":any,"has_default":True,"default":None},
+
+
+
+            #++++++++++++++++++++++++++++++ Model Optmization(Clustering,Classification) ++++++++++++++++++++++++++++++#
+
+            "class_to_optimize_for": {"type":any,"has_default":False},
+            "dir_for_conf": {"type":str,"has_default":True,"default":"Maximize"},
+            "constrains": {"type":str,"has_default":True,"default":""},
+            "stay_within": {"type":bool,"has_default":True,"default":False},
+            "stay_below": {"type":bool,"has_default":True,"default":True},
+            "stay_above": {"type":bool,"has_default":True,"default":True},
+            "stay_within_num": {"type":any,"has_default":True,"default":None}
+    }
     @classmethod
 
     def GetParamsMappingsDictionary(cls,expected_keys_list):
@@ -78,14 +136,12 @@ class RequestParser():
             properties=self._expected_keys[key]
             if properties["type"]==self.DICTIONARY_LIST_TYPE :
                 keyValues=self._passed_request.data.getlist(key)
-                print(keyValues)
-                if isinstance(keyValues,str):
-                    keyValues=[json.loads(keyValues)]
-                else:
-                    for dict_str in keyValues:
-                         dict_str=json.loads(dict_str)
-                self._request_dict[key]=keyValues
-                print(self._request_dict[key])
+                convertedValues=[]
+                for dict_str in keyValues:
+                        dict_str=json.loads(dict_str)
+                        convertedValues.append(dict_str)
+                self._request_dict[key]=convertedValues
+
             elif properties["type"]==list:
                 self._request_dict[key]=self._request_dict.getlist(key)
             elif properties["type"]==dict:
@@ -98,23 +154,22 @@ class RequestParser():
             # if isinstance(self._request_dict[key]["type"]
         # for key,value in passedFormData.items():
         #     self.passedFormData[key]=str(value) if self._expected_keys[key]=="String" else int(value) if self._expected_keys[key]=="Number" else float(value) if self._expected_keys[key]=="Decimal" else str(value) if self._expected_keys[key]=="String"
-        
         status,validation_response=self._ValidateRequest()
         self._passed_request.data._mutable=False
+        print(validation_response)
         return status,validation_response
 
 
     def _ValidateRequest(self):
+
         requestkeys=self._request_dict.keys()
         notFoundKeysInRequest=[]
         for key,value in self._expected_keys.items():
             if key in requestkeys:
                 if value["type"]==self.DICTIONARY_LIST_TYPE:
-                    try:
-                        self._request_dict[key]=self._request_dict[key]
-                    except:
-                        example=value.get("example")
-                        notFoundKeysInRequest.append(f"{key}:value like {example}")
+
+                        # example=value.get("example")
+                        # notFoundKeysInRequest.append(f"{key}:value like {example}")
                     continue
 
                 elif value["type"]==dict:
@@ -136,12 +191,11 @@ class RequestParser():
                         notFoundKeysInRequest.append(f"{key}:should be map key:value")
 
                 elif value["type"]==bool:
-                    if not isinstance(self._request_dict[key],dict):
+                    if not isinstance(self._request_dict[key],bool):
                         notFoundKeysInRequest.append(f"{key}:should be boolean True,False")
                 elif value["type"]==any:
                     continue
                 else:
-                    print(self._request_dict[key],value["type"])
                     if not isinstance(self._request_dict[key],value["type"]):
                         notFoundKeysInRequest.append(f"{key}:should be {'number' if value['type']==int else 'decimal' if value['type']==float else 'text'}")
                     self._request_dict[key]=value["type"](self._request_dict[key])
@@ -157,7 +211,7 @@ class RequestParser():
         passedFiles=self._passed_request.FILES.getlist("files",[])
         passedFilesData=[]
         if passedFiles!=[]:
-            status,response=ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.UPLOAD_FILES_FROM_SERVICE,self._passed_request,Services.DATA_KEY)
+            status,response=ServiceController.CallEurekaService(service_name=Services.FILE_SERVICE_NAME,service_url=Services.UPLOAD_FILES_FROM_SERVICE,data=self._passed_request,response_key=Services.DATA_KEY)
             if not status:
                 return response
 
@@ -166,7 +220,7 @@ class RequestParser():
 
         if self._request_dict["file_path_info"] is not None and self._request_dict["file_path_info"] !=[] :
 
-            status,response=ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.READ_DF_FILE_FROM_SERVICE,{"file_path_info":self._request_dict["file_path_info"]},Services.DATA_KEY)
+            status,response=ServiceController.CallEurekaService(service_name=Services.FILE_SERVICE_NAME,service_url=Services.READ_DF_FILE_FROM_SERVICE,data={"file_path_info":self._request_dict["file_path_info"]},response_key=Services.DATA_KEY)
             if not status:
                 return response
     
@@ -181,7 +235,7 @@ class RequestParser():
         passedFiles=None if file_path_info=={} else self._passed_request.FILES.get("files",None)
         passedFilesData=[]
         if passedFiles is not None:
-            status,response=ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.FILE_SERVICE_NAME,Services.UPLOAD_FILES_FROM_SERVICE,{"files":base64.b64encode(self._passed_request.FILES.get("files").read()).decode()},Services.DATA_KEY)
+            status,response=ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.UPLOAD_FILES_FROM_SERVICE,Services.UPLOAD_FILES_FROM_SERVICE,data={"files":base64.b64encode(self._passed_request.FILES.get("files").read()).decode()},response_key=Services.DATA_KEY)
             if not status:
                 return response
             
@@ -190,7 +244,7 @@ class RequestParser():
 
 
         fileToRead=file_path_info["file_path_info"] if file_path_info!={} else self._request_dict["file_path_info"] 
-        status,response=ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.FILE_SERVICE_NAME,Services.READ_DF_FILE,{"file_path_info":fileToRead[0:1] if isinstance(fileToRead,list) else [fileToRead]},Services.DATA_KEY)
+        status,response=ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.READ_DF_FILE,data={"file_path_info":fileToRead[0:1] if isinstance(fileToRead,list) else [fileToRead]},response_key=Services.DATA_KEY)
         if not status:
             return response
         
@@ -234,18 +288,16 @@ class RequestParser():
         return True,outfilename
 
     def ReadPickle(self,pickle_path:str,pickle_type="model"):
-        serviceController=ServiceController(Services.FILE_SERVICE_NAME)
-        serviceCallResults= serviceController.CallEurekaService(Services.LOAD_PICKLE,data={"pickle_path":pickle_path,"pickle_type":pickle_type},response_key=Services.DATA_KEY)
+        serviceCallResults,serviceCallResponse= ServiceController.CallEurekaService(Services.FILE_SERVICE_NAME,Services.LOAD_PICKLE,data={"pickle_path":pickle_path,"pickle_type":pickle_type},response_key=Services.DATA_KEY)
 
         if not serviceCallResults:
                 return False,{'message':serviceCallResults["message"],"code":422}
-        readResult=serviceController._response_data
-        readResult[pickle_path]=Base64Converter.B64ToPickle(readResult[str(pickle_path)])
-        if "TransformersObjects" in readResult.keys() and readResult["TransformersObjects"]!={}:
-            transformerObjects=readResult["TransformersObjects"]
+        serviceCallResponse[pickle_path]=Base64Converter.B64ToPickle(serviceCallResponse[str(pickle_path)])
+        if "TransformersObjects" in serviceCallResponse.keys() and serviceCallResponse["TransformersObjects"]!={}:
+            transformerObjects=serviceCallResponse["TransformersObjects"]
             for pickle_name,pickle_b64 in transformerObjects.items():
                 transformerObjects[pickle_name]=Base64Converter.B64ToPickle(pickle_b64)
-        return True,readResult
+        return True,serviceCallResponse
     def ReturnErrorMessage(self,error_message=None):
         if not error_message:
             return HttpResponse(json.dumps({'status': False, 'message': ",".join(i for i in self._error)}), status=422,
